.. module:: enaml.widgets.stack

===================
enaml.widgets.stack
===================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Transition
    Stack


.. autoclass:: Transition

.. autoclass:: Stack
